@@ -30,6 +30,8 @@ from astx.blocks import (
     Block,
 )
 from astx.callables import (
+    Argument,
+    Arguments,
     Function,
     FunctionCall,
     FunctionPrototype,
@@ -53,8 +55,20 @@ from astx.datatypes import (
     LiteralInt16,
     LiteralInt32,
     LiteralInt64,
+    LiteralInt128,
+    LiteralUInt8,
+    LiteralUInt16,
+    LiteralUInt32,
+    LiteralUInt64,
+    LiteralUInt128,
     Number,
     SignedInteger,
+    UInt8,
+    UInt16,
+    UInt32,
+    UInt64,
+    UInt128,
+    UnsignedInteger,
 )
 from astx.flows import (
     ForCountLoop,
@@ -76,8 +90,6 @@ from astx.operators import (
 )
 from astx.packages import Module, Package, Program, Target
 from astx.variables import (
-    Argument,
-    Arguments,
     InlineVariableDeclaration,
     Variable,
     VariableAssignment,
@@ -90,7 +102,7 @@ def get_version() -> str:
     try:
         return importlib_metadata.version(__name__)
     except importlib_metadata.PackageNotFoundError:  # pragma: no cover
-        return "0.13.0"  # semantic-release
+        return "0.14.0"  # semantic-release
 
 
 __all__ = [
@@ -128,12 +140,24 @@ __all__ = [
     "Int64",
     "Int8",
     "Integer",
+    "UnsignedInteger",
+    "UInt8",
+    "UInt16",
+    "UInt32",
+    "UInt64",
+    "UInt128",
     "Literal",
     "LiteralBoolean",
+    "LiteralInt8",
     "LiteralInt16",
     "LiteralInt32",
     "LiteralInt64",
-    "LiteralInt8",
+    "LiteralInt128",
+    "LiteralUInt8",
+    "LiteralUInt16",
+    "LiteralUInt32",
+    "LiteralUInt64",
+    "LiteralUInt128",
     "mixes",
     "Module",
     "MutabilityKind",
